{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
   ],
   "source": [
    "from pyalgotrade.bar import Bar\n",
    "from pyalgotrade import barfeed\n",
    "\n",
    "class PandasBar(Bar):\n",
    "\n",
    "    def __init__(self, df, ix, bars):\n",
    "        self.df = df\n",
    "        self.ix = ix\n",
    "        self.bars = bars\n",
    "\n",
    "    def getRow(self):\n",
    "        rowkey = self.df.index[self.ix]\n",
    "        return self.df.ix[rowkey]\n",
    "\n",
    "    def getDateTime(self):\n",
    "        \"\"\"Returns the :class:`datetime.datetime`.\"\"\"\n",
    "        return self.bars.date\n",
    "\n",
    "    def getOpen(self, adjusted=False):\n",
    "        \"\"\"Returns the opening price.\"\"\"\n",
    "        ret = ( float(self.getRow()[\"Ask\"]) + float(self.getRow()[\"Bid\"]) ) / 2\n",
    "        if ret > 0:\n",
    "            return ret\n",
    "        else:\n",
    "            return 0.01 #fix for worthless options\n",
    "        \n",
    "    def getHigh(self, adjusted=False):\n",
    "        \"\"\"Returns the highest price.\"\"\"\n",
    "        return float(self.getRow()[\"Ask\"])\n",
    "\n",
    "    def getLow(self, adjusted=False):\n",
    "        \"\"\"Returns the lowest price.\"\"\"\n",
    "        return float(self.getRow()[\"Bid\"])\n",
    "\n",
    "    def getClose(self, adjusted=False):\n",
    "        \"\"\"Returns the closing price.\"\"\"\n",
    "        return self.getOpen()\n",
    "\n",
    "    def getVolume(self):\n",
    "        \"\"\"Returns the volume.\"\"\"\n",
    "        return 500000\n",
    "\n",
    "    def getAdjClose(self):\n",
    "        \"\"\"Returns the adjusted closing price.\"\"\"\n",
    "        return self.getOpen()\n",
    "\n",
    "    def getFrequency(self):\n",
    "        \"\"\"The bar's period.\"\"\"\n",
    "        return barfeed.Frequency.DAY\n",
    "\n",
    "    def getPrice(self):\n",
    "        \"\"\"Returns the closing or adjusted closing price.\"\"\"\n",
    "        return self.getOpen()\n",
    "\n",
    "    def setUseAdjustedValue(self, useAdjusted):\n",
    "        pass\n",
    "\n",
    "    def getUseAdjValue(self):\n",
    "        return False"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
   ],
   "source": [
    "class PandasBars(object):\n",
    "\n",
    "    \"\"\"A group of :class:`Bar` objects.\n",
    "    :param barDict: A map of instrument to :class:`Bar` objects.\n",
    "    :type barDict: map.\n",
    "    .. note::\n",
    "        All bars must have the same datetime.\n",
    "    \"\"\"\n",
    "\n",
    "    def __init__(self, df, date, arr_ix=[]):\n",
    "        self.date = date\n",
    "        self.df = df\n",
    "        self.arr_ix = arr_ix\n",
    "\n",
    "        #key_val_arr = map(lambda ix: (df.ix[df.index[ix]][\"Symbol\"], PandasBar(df, ix, self)), self.arr_ix)\n",
    "        #self.bar_dict = dict(key_val_arr)\n",
    "\n",
    "    def set_bars_dict(self, bar_dict):\n",
    "        self.bar_dict = bar_dict\n",
    "\n",
    "    def keys(self):\n",
    "        return self.bar_dict.keys()\n",
    "\n",
    "    def __getitem__(self, instrument):\n",
    "        \"\"\"Returns the :class:`pyalgotrade.bar.Bar` for the given instrument.\n",
    "        If the instrument is not found an exception is raised.\"\"\"\n",
    "        return self.bar_dict[instrument]\n",
    "\n",
    "    def __contains__(self, instrument):\n",
    "        \"\"\"Returns True if a :class:`pyalgotrade.bar.Bar` for the given instrument is available.\"\"\"\n",
    "        return instrument in self.bar_dict\n",
    "\n",
    "    def items(self):\n",
    "        return self.bar_dict.items()\n",
    "\n",
    "    def keys(self):\n",
    "        return self.bar_dict.keys()\n",
    "\n",
    "    def getInstruments(self):\n",
    "        \"\"\"Returns the instrument symbols.\"\"\"\n",
    "        return self.bar_dict.keys()\n",
    "\n",
    "    def getDateTime(self):\n",
    "        \"\"\"Returns the :class:`datetime.datetime` for this set of bars.\"\"\"\n",
    "        return self.date\n",
    "    \n",
    "    def setDateTime(self, date):\n",
    "        self.date = date\n",
    "\n",
    "    def getBar(self, instrument):\n",
    "        \"\"\"Returns the :class:`pyalgotrade.bar.Bar` for the given instrument or None if the instrument is not found.\"\"\"\n",
    "        return self.bar_dict.get(instrument, None)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
   ],
   "source": [
    "from more_itertools import peekable\n",
    "from pyalgotrade.bar import Bar\n",
    "from pyalgotrade import barfeed\n",
    "import datetime\n",
    "\n",
    "class PandasBarFeed(barfeed.BaseBarFeed):\n",
    "    def __init__(self, dataframe, instrument, frequency):\n",
    "        super(PandasBarFeed, self).__init__(frequency)\n",
    "        self.registerInstrument(instrument)\n",
    "        self.__df = dataframe\n",
    "        self.__instrument = instrument\n",
    "        self.__next = 0\n",
    "        self.started = False\n",
    "        self.signal_bar = None\n",
    "        self.__lastBars = {}\n",
    "\n",
    "        groups = self.__df.groupby([\"DateType\",\"Symbol\"]).groups\n",
    "        timestamp_dict = {}\n",
    "        bars_dict = {}\n",
    "\n",
    "        def loadBars(timestamp, symbol, index):            \n",
    "            if timestamp not in timestamp_dict:\n",
    "                timestamp_dict[timestamp] = {}\n",
    "                bars_dict[timestamp] = PandasBars(self.__df, timestamp)\n",
    "\n",
    "            timestamp_dict[timestamp][symbol] = PandasBar(self.__df, index, bars_dict[timestamp])\n",
    "\n",
    "        map(lambda ((timestamp, symbol),index):loadBars(timestamp, symbol, index), groups.iteritems())\n",
    "        map(lambda (timestamp, bars):bars.set_bars_dict(timestamp_dict[timestamp]), bars_dict.iteritems())\n",
    "\n",
    "        dates = sorted(timestamp_dict.keys())\n",
    "        bars = map(lambda d:bars_dict[d], dates)\n",
    "        \n",
    "        self.bars = []\n",
    "        for bar in bars:\n",
    "            self.bars.append(bar)\n",
    "            #trade_bar = PandasBars(bar.df, bar.date+datetime.timedelta(minutes=30),bar.arr_ix)\n",
    "            #trade_bar.set_bars_dict(bar.bar_dict)\n",
    "            #self.bars.append(trade_bar)\n",
    "        \n",
    "        self.bar_iter = peekable(self.bars)\n",
    "\n",
    "    def reset(self):\n",
    "        super(PandasBarFeed, self).reset()\n",
    "        self.bar_iter = peekable(self.bars)\n",
    "        self.started = False\n",
    "        self.__lastBars = {}\n",
    "\n",
    "    def peekDateTime(self):\n",
    "        return self.getCurrentDateTime()\n",
    "\n",
    "    def getCurrentDateTime(self):\n",
    "        try:\n",
    "            return self.bar_iter.peek().date\n",
    "        except StopIteration:\n",
    "            return None\n",
    "\n",
    "    def barsHaveAdjClose(self):\n",
    "        return True\n",
    "\n",
    "    def getNextBars(self):\n",
    "        try:\n",
    "            return self.bar_iter.next()\n",
    "        except StopIteration:\n",
    "            return None\n",
    "\n",
    "    def start(self):\n",
    "        #super(PandasBarFeed, self).start()\n",
    "        self.__started = True\n",
    "\n",
    "    def stop(self):\n",
    "        pass\n",
    "\n",
    "    def join(self):\n",
    "        pass\n",
    "\n",
    "    def eof(self):\n",
    "        try:\n",
    "            if self.bar_iter.peek() and not self.bar_iter.peek() == self.bars[-1]:\n",
    "                return False\n",
    "            else:\n",
    "                return True\n",
    "        except StopIteration:\n",
    "            return True\n",
    "\n",
    "    def getCurrentBars(self):\n",
    "        try:\n",
    "            return self.bar_iter.peek()\n",
    "        except StopIteration:\n",
    "            return None\n",
    "\n",
    "    def getNextValuesAndUpdateDS(self):\n",
    "        dateTime, values = self.getNextValues()\n",
    "        return (dateTime, values)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
   ],
   "source": [
    "import pandas as pd\n",
    "df = pd.read_csv(\"vxx_csv3.csv\", parse_dates=['DateType'])\n",
    "feed = PandasBarFeed(df, \"VXX\", barfeed.Frequency.TRADE)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<class 'pandas.core.frame.DataFrame'>\n",
      "RangeIndex: 868602 entries, 0 to 868601\n",
      "Data columns (total 11 columns):\n",
      "Unnamed: 0         868602 non-null int64\n",
      "Symbol             868602 non-null object\n",
      "DateType           868602 non-null datetime64[ns]\n",
      "Type               867324 non-null object\n",
      "ExpDate            867324 non-null object\n",
      "Strike             867324 non-null float64\n",
      "Last               868602 non-null float64\n",
      "Bid                868602 non-null float64\n",
      "Ask                868602 non-null float64\n",
      "Volume             868602 non-null int64\n",
      "UnderlyingPrice    867324 non-null float64\n",
      "dtypes: datetime64[ns](1), float64(5), int64(2), object(3)\n",
      "memory usage: 72.9+ MB\n"
     ]
    }
   ],
   "source": [
    "df.info()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
   ],
   "source": [
    "#!/usr/bin/python\n",
    "# This file contains functions to help with detecting trading holidays\n",
    "# It relies on Pandas, Numpy (via Pandas) and Datetime\n",
    "\n",
    "import datetime as dt\n",
    "\n",
    "from pandas.tseries.holiday import AbstractHolidayCalendar, Holiday, nearest_workday, USMartinLutherKingJr, USPresidentsDay, USMemorialDay, USLaborDay, USThanksgivingDay\n",
    "# Import seperately to define GoodFriday due to old pandas version\n",
    "from pandas.tseries.offsets import Easter, Day\n",
    "\n",
    "\n",
    "class USTradingCalendar(AbstractHolidayCalendar):\n",
    "    def __init__(self):\n",
    "        # This is needed for older versions of Pandas pre-v15 and is forward compatible:\n",
    "        GoodFriday = GoodFriday = Holiday(\"Good Friday\", month=1, day=1, offset=[Easter(), Day(-2)])\n",
    "        USTradingCalendar.rules.append(GoodFriday)\n",
    "    rules = [\n",
    "        Holiday('NewYearsDay', month=1, day=1, observance=nearest_workday),\n",
    "        USMartinLutherKingJr,\n",
    "        USPresidentsDay,\n",
    "        USMemorialDay,\n",
    "        Holiday('USIndependenceDay', month=7, day=4, observance=nearest_workday),\n",
    "        USLaborDay,\n",
    "        USThanksgivingDay,\n",
    "        Holiday('Christmas', month=12, day=25, observance=nearest_workday)\n",
    "    ]\n",
    "\n",
    "    def is_market_closed(self,dto):\n",
    "        # True if a given dt object is a trading holiday\n",
    "        inst = USTradingCalendar()\n",
    "        cal = inst.holidays(dt.datetime(dto.year-1, 12, 31), dt.datetime(dto.year, 12, 31))\n",
    "        if dto in cal:\n",
    "            return True\n",
    "        else:\n",
    "            return False\n",
    "\n",
    "def get_trading_holidays(year, n_years=0):\n",
    "    # Returns a list of trading holidays for a given year\n",
    "    inst = USTradingCalendar()\n",
    "    return inst.holidays(dt.datetime(year-1, 12, 31), dt.datetime(year + n_years, 12, 31))\n",
    "\n",
    "def is_trading_holiday(dto):\n",
    "    # True if a given dt object is a trading holiday\n",
    "    inst = USTradingCalendar()\n",
    "    cal = inst.holidays(dt.datetime(dto.year-1, 12, 31), dt.datetime(dto.year, 12, 31))\n",
    "    if dto in cal:\n",
    "        return True\n",
    "    else:\n",
    "        return False\n",
    "\n",
    "    \n",
    "cal = get_trading_holidays(2014, n_years=2)\n",
    "    \n",
    "def get_last_trading_day(expiration_date):\n",
    "    \n",
    "    if expiration_date in cal or expiration_date.weekday() == 6 or expiration_date.weekday() == 5:\n",
    "        return get_last_trading_day(expiration_date - dt.timedelta(days=1))\n",
    "    \n",
    "    return expiration_date\n",
    "\n",
    "def get_next_trading_day(date):\n",
    "    next_date = date + dt.timedelta(days=1)\n",
    "    \n",
    "    if next_date in cal or next_date.weekday() == 6 or next_date.weekday() == 5:\n",
    "        return get_next_trading_day(next_date)\n",
    "    \n",
    "    return next_date"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
   ],
   "source": [
    "from pyalgotrade import strategy\n",
    "from pyalgotrade.broker import backtesting\n",
    "from vollib.black_scholes.implied_volatility import implied_volatility\n",
    "from vollib.black_scholes.greeks.numerical import delta\n",
    "import math\n",
    "import datetime\n",
    "\n",
    "class MyStrategy(strategy.BacktestingStrategy):\n",
    "    \n",
    "    def __init__(self, feed, instrument, useAdjustedClose=True, max_allocation=0.32, cash=100000):\n",
    "        strategy.BacktestingStrategy.__init__(self, feed, cash)\n",
    "        self.setUseAdjustedValues(useAdjustedClose)\n",
    "        self.__instrument = instrument\n",
    "        self.max_allocation = max_allocation\n",
    "        self.chain = None\n",
    "        self.liquidated = False\n",
    "        self.expiration_date = None\n",
    "        self.getBroker().setCommission(backtesting.TradePercentage(0.0))\n",
    "\n",
    "    def check_split(self, current_date):\n",
    "        \"\"\"\n",
    "        Return true if a split occurs next trading day\n",
    "        \"\"\"\n",
    "        vxx_splits = [datetime.date(2010,11,9), datetime.date(2012, 10, 5), datetime.date(2013, 11, 8), datetime.date(2016,8,9), datetime.date(2017,1,27)]\n",
    "        next_trading_day = get_next_trading_day(current_date)\n",
    "        previous_day = current_date - datetime.timedelta(days=1)\n",
    "        for d in vxx_splits:\n",
    "            if next_trading_day == d or current_date == d or previous_day == d:\n",
    "                self.info(\"A split will occur on {0}.\".format(current_date))\n",
    "                return True\n",
    "\n",
    "        return False\n",
    "    \n",
    "    def calc_delta(self, filtered_option_chain, bars, t):\n",
    "        chains = []\n",
    "\n",
    "        for option in filtered_option_chain:\n",
    "            price = float(bars[option['OptionSymbol']].getClose())\n",
    "            cp = option['Type'].lower()\n",
    "            K = float(option['Price'])\n",
    "            S = float((bars['VXX']).getClose())\n",
    "            r = 0.028\n",
    "\n",
    "            iv = implied_volatility(price, S, K, t, r, str(cp))\n",
    "            calc_delta = delta(str(cp), S, K, t, r, float(iv))\n",
    "\n",
    "            option[\"IV\"] = iv\n",
    "            option[\"Delta\"] = calc_delta\n",
    "            chains.append(option)\n",
    "\n",
    "        return chains\n",
    "\n",
    "    def get_closet_expiration(self, n_days, chain):\n",
    "        current_datetime = (self.getCurrentDateTime()).date()\n",
    "        expiration_datetime = current_datetime + datetime.timedelta(days=n_days)\n",
    "        option_chain = filter(lambda option:option['Expiration'] > expiration_datetime, chain)\n",
    "        expiration_dates = map(lambda option:option['Expiration'], option_chain)\n",
    "        \n",
    "        if len(expiration_dates) > 1:\n",
    "            return min(expiration_dates)\n",
    "        else:\n",
    "            return None\n",
    "    \n",
    "    def get_chain(self, bars):\n",
    "        def parse_option_symbol(symbol):\n",
    "            try:\n",
    "                opra_symbol = symbol[:-15]\n",
    "                opra_expiry = datetime.datetime.strptime(symbol[-15:-9], '%y%m%d').date()\n",
    "                opra_cp = symbol[-9]\n",
    "                opra_price = int(symbol[-8:]) * .001\n",
    "\n",
    "                return {\"Symbol\":opra_symbol, \"Expiration\":opra_expiry, \"Type\":opra_cp, \"Price\":opra_price, \"OptionSymbol\":symbol}\n",
    "            except:\n",
    "                print \"Symbol:\" + symbol\n",
    "                print \"OpraSymbol:\" + symbol[:-15]\n",
    "                print \"OpraExpiry:\" + symbol[-15:-9]\n",
    "                print \"OpraCp:\" + symbol[-9]\n",
    "                print \"OpraPrice:\" + symbol[-8]\n",
    "\n",
    "        chain = []\n",
    "        for symbol in bars.keys():\n",
    "            if symbol == \"VXX\":\n",
    "                continue\n",
    "\n",
    "            chain.append(parse_option_symbol(symbol))\n",
    "\n",
    "        return chain    \n",
    "    \n",
    "    def enterPosition(self, bars):\n",
    "        portfolioAmt = self.getBroker().getEquity()\n",
    "\n",
    "        atm_delta = 0.55\n",
    "        otm_delta = 0.42\n",
    "        close = bars[\"VXX\"].getClose()\n",
    "        original_option_chain = self.get_chain(bars)\n",
    "        self.expiration_date = self.get_closet_expiration(14, original_option_chain)\n",
    "        short_expiration_date = self.get_closet_expiration(7, original_option_chain)\n",
    "        self.short_expiration_date = short_expiration_date\n",
    "        \n",
    "        if self.expiration_date == None:\n",
    "            return None\n",
    "        \n",
    "        option_chain = filter(lambda option:option['Expiration'] == self.expiration_date, original_option_chain)\n",
    "        short_chain = filter(lambda option:option['Expiration'] == short_expiration_date, original_option_chain)\n",
    "\n",
    "        current_datetime = (self.getCurrentDateTime()).date()\n",
    "        t = float(((self.expiration_date - current_datetime).total_seconds()) / (60 * 60 * 24 * 365))\n",
    "\n",
    "        put_option_chain = filter(lambda option:option['Type'] == 'P', option_chain)\n",
    "        short_put_option_chain = filter(lambda option:option['Type'] == 'P', short_chain)\n",
    "        self.calc_delta(put_option_chain, bars, t)\n",
    "        self.calc_delta(short_put_option_chain, bars, t)\n",
    "\n",
    "        try:\n",
    "            self.atm_put_option = min(put_option_chain, key=lambda option:math.fabs(atm_delta - math.fabs(float(option['Delta']))))\n",
    "            self.otm_put_option = min(short_put_option_chain, key=lambda option:math.fabs(otm_delta - math.fabs(float(option['Delta']))))\n",
    "        except:\n",
    "            return None\n",
    "        \n",
    "        if float((bars[self.atm_put_option['OptionSymbol']]).getClose()) - float((bars[self.otm_put_option['OptionSymbol']]).getClose()) <= 0:\n",
    "            return None\n",
    "        \n",
    "        self.put_debit = float((bars[self.atm_put_option['OptionSymbol']]).getClose()) - float((bars[self.otm_put_option['OptionSymbol']]).getClose())\n",
    "        \n",
    "        self.info(\"Portfolio Amount:\" + str(portfolioAmt) + \" Allotted Portfolio Amount: \" + str(portfolioAmt * 0.10))\n",
    "        self.shares = (portfolioAmt * 0.10) / self.put_debit\n",
    "\n",
    "        if self.shares <= 0:\n",
    "            return None\n",
    "\n",
    "        self.positions = []\n",
    "        self.positions.append(self.enterLong(self.atm_put_option['OptionSymbol'], self.shares, goodTillCanceled=True))\n",
    "        self.positions.append(self.enterShort(self.otm_put_option['OptionSymbol'], self.shares, goodTillCanceled=True))\n",
    "        self.info(\"Enter Position: +\" + str(self.shares) + \" \" + self.atm_put_option['OptionSymbol'] + \" -\" + str(self.shares) + \" \" + self.otm_put_option['OptionSymbol'] + \" at price \" + str(self.put_debit) + \"; VXX: \" + str(close))\n",
    "        \n",
    "        return self.positions\n",
    "    \n",
    "    def onBars(self, bars):\n",
    "        if \"VXX\" not in bars.keys():\n",
    "            return\n",
    "        \n",
    "        if self.liquidated == False and self.expiration_date != None:\n",
    "            if self.getCurrentDateTime() == None:\n",
    "                return\n",
    "\n",
    "            current_datetime = self.getCurrentDateTime().date()\n",
    "            #current_datetime = dateTime.date()\n",
    "            percentage = 0\n",
    "            current_put_credit = 0\n",
    "            \n",
    "            if hasattr(self, \"atm_put_option\"): #current P/L\n",
    "                try:\n",
    "                    current_put_credit = float((bars[self.atm_put_option['OptionSymbol']]).getClose()) - float((bars[self.otm_put_option['OptionSymbol']]).getClose())\n",
    "                    percentage = math.fabs(current_put_credit / self.put_debit)\n",
    "                except:\n",
    "                    self.info(\"Key Error\") #Sometimes HOD doesn't have the data; skip this time and hope we find it the next day\n",
    "                    return\n",
    "            \n",
    "            last_trading_day = get_last_trading_day(self.short_expiration_date) - datetime.timedelta(days=1)\n",
    "            \n",
    "            if (self.expiration_date != None) and (current_datetime >= last_trading_day or percentage >= 1.30 or percentage <= 0.75 or self.check_split(current_datetime)):\n",
    "                    exit_spread_str = \"\"\n",
    "                    exit_pnl = 0\n",
    "                    for position in self.positions:\n",
    "                        exit_spread_str = exit_spread_str + str(position.getShares()) + \" \" + str(position.getInstrument()) + \" \"\n",
    "                        exit_pnl = exit_pnl + position.getPnL()\n",
    "                        #self.marketOrder(position.getInstrument(), -position.getShares(), onClose=True)\n",
    "                        position.exitMarket()\n",
    "                    \n",
    "                    self.info(\"Exit \" + exit_spread_str +\" at price \" + str(current_put_credit) + \"; PnL: \" + str(exit_pnl) + \"; VXX: \" + str(bars[\"VXX\"].getClose()))\n",
    "                    \n",
    "                    #self.info(\"Exit \" + self.atm_put_option['OptionSymbol'])\n",
    "                    self.liquidated = True\n",
    "\n",
    "        if (self.liquidated == True) or self.expiration_date == None:\n",
    "            current_datetime = (self.getCurrentDateTime() - datetime.timedelta(minutes=30)).date()\n",
    "            \n",
    "            if self.check_split(current_datetime) == False:\n",
    "                success = self.enterPosition(bars)\n",
    "\n",
    "                if success:\n",
    "                    self.liquidated = False"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "collapsed": false,
    "scrolled": true
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-01 00:00:00 strategy [INFO] Portfolio Amount:100000 Allotted Portfolio Amount: 10000.0\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-01 00:00:00 strategy [INFO] Enter Position: +7434.94423792 VXX110917P00041000 -7434.94423792 VXX110917P00039000 at price 1.345; VXX: 39.49\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-06 00:00:00 strategy [INFO] Exit 7434 VXX110917P00041000 -7434 VXX110917P00039000  at price 0.825; PnL: -1672.65; VXX: 42.72\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-06 00:00:00 strategy [INFO] Portfolio Amount:99739.81 Allotted Portfolio Amount: 9973.981\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-06 00:00:00 strategy [INFO] Enter Position: +1673.48674497 VXX111022P00047000 -1673.48674497 VXX110917P00042000 at price 5.96; VXX: 42.72\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-14 00:00:00 strategy [INFO] Exit 1673 VXX111022P00047000 -1673 VXX110917P00042000  at price 6.135; PnL: -41.825; VXX: 44.6\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-14 00:00:00 strategy [INFO] Portfolio Amount:101203.685 Allotted Portfolio Amount: 10120.3685\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-14 00:00:00 strategy [INFO] Enter Position: +3892.44942308 VXX111022P00048000 -3892.44942308 VXX111022P00044000 at price 2.6; VXX: 44.6\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-22 00:00:00 strategy [INFO] Exit 3892 VXX111022P00048000 -3892 VXX111022P00044000  at price 1.89; PnL: -3930.92; VXX: 49.84\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-22 00:00:00 strategy [INFO] Portfolio Amount:96883.565 Allotted Portfolio Amount: 9688.3565\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-09-22 00:00:00 strategy [INFO] Enter Position: +2958.27679389 VXX111022P00054000 -2958.27679389 VXX111022P00049000 at price 3.275; VXX: 49.84\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-03 00:00:00 strategy [INFO] Exit 2958 VXX111022P00054000 -2958 VXX111022P00049000  at price 1.925; PnL: -3475.65; VXX: 56.84\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-03 00:00:00 strategy [INFO] Portfolio Amount:95596.835 Allotted Portfolio Amount: 9559.6835\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-03 00:00:00 strategy [INFO] Enter Position: +3901.91163265 VXX111022P00060000 -3901.91163265 VXX111022P00056000 at price 2.45; VXX: 56.84\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-05 00:00:00 strategy [INFO] Exit 3901 VXX111022P00060000 -3901 VXX111022P00056000  at price 3.3; PnL: 877.725; VXX: 50.26\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-05 00:00:00 strategy [INFO] Portfolio Amount:97157.235 Allotted Portfolio Amount: 9715.7235\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-05 00:00:00 strategy [INFO] Enter Position: +3840.206917 VXX111022P00053000 -3840.206917 VXX111022P00049000 at price 2.53; VXX: 50.26\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-12 00:00:00 strategy [INFO] Exit 3840 VXX111022P00053000 -3840 VXX111022P00049000  at price 3.675; PnL: 4032.0; VXX: 42.97\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-12 00:00:00 strategy [INFO] Portfolio Amount:101381.235 Allotted Portfolio Amount: 10138.1235\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-12 00:00:00 strategy [INFO] Enter Position: +1834.95447964 VXX111119P00047000 -1834.95447964 VXX111022P00042000 at price 5.525; VXX: 42.97\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-19 00:00:00 strategy [INFO] Exit 1834 VXX111119P00047000 -1834 VXX111022P00042000  at price 5.415; PnL: -596.05; VXX: 45.87\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-19 00:00:00 strategy [INFO] Portfolio Amount:100610.955 Allotted Portfolio Amount: 10061.0955\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-19 00:00:00 strategy [INFO] Enter Position: +3119.71953488 VXX111119P00050000 -3119.71953488 VXX111119P00045000 at price 3.225; VXX: 45.87\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-27 00:00:00 strategy [INFO] Exit 3119 VXX111119P00050000 -3119 VXX111119P00045000  at price 4.575; PnL: 4366.6; VXX: 36.45\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-27 00:00:00 strategy [INFO] Portfolio Amount:104977.555 Allotted Portfolio Amount: 10497.7555\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-27 00:00:00 strategy [INFO] Enter Position: +5275.2540201 VXX111119P00039000 -5275.2540201 VXX111119P00036000 at price 1.99; VXX: 36.45\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-31 00:00:00 strategy [INFO] Exit 5275 VXX111119P00039000 -5275 VXX111119P00036000  at price 1.34; PnL: -3877.125; VXX: 40.11\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-31 00:00:00 strategy [INFO] Portfolio Amount:97645.305 Allotted Portfolio Amount: 9764.5305\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-10-31 00:00:00 strategy [INFO] Enter Position: +5394.76823204 VXX111119P00042000 -5394.76823204 VXX111119P00039000 at price 1.81; VXX: 40.11\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-01 00:00:00 strategy [INFO] Exit 5394 VXX111119P00042000 -5394 VXX111119P00039000  at price 1.045; PnL: 0.0; VXX: 45.92\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-01 00:00:00 strategy [INFO] Portfolio Amount:98184.705 Allotted Portfolio Amount: 9818.4705\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-01 00:00:00 strategy [INFO] Enter Position: +3850.38058824 VXX111119P00049000 -3850.38058824 VXX111119P00045000 at price 2.55; VXX: 45.92\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-08 00:00:00 strategy [INFO] Exit 3850 VXX111119P00049000 -3850 VXX111119P00045000  at price 3.425; PnL: 2406.25; VXX: 40.82\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-08 00:00:00 strategy [INFO] Portfolio Amount:95181.705 Allotted Portfolio Amount: 9518.1705\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-08 00:00:00 strategy [INFO] Enter Position: +1760.99361702 VXX111217P00045000 -1760.99361702 VXX111119P00040000 at price 5.405; VXX: 40.82\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-09 00:00:00 strategy [INFO] Exit 1760 VXX111217P00045000 -1760 VXX111119P00040000  at price 3.795; PnL: 0.0; VXX: 48.52\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-09 00:00:00 strategy [INFO] Portfolio Amount:96660.105 Allotted Portfolio Amount: 9666.0105\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-09 00:00:00 strategy [INFO] Enter Position: +1453.53541353 VXX111217P00054000 -1453.53541353 VXX111119P00048000 at price 6.65; VXX: 48.52\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-16 00:00:00 strategy [INFO] Exit 1453 VXX111217P00054000 -1453 VXX111119P00048000  at price 7.84; PnL: 1111.545; VXX: 46.29\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-16 00:00:00 strategy [INFO] Portfolio Amount:98040.455 Allotted Portfolio Amount: 9804.0455\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-11-16 00:00:00 strategy [INFO] Enter Position: +3807.39631068 VXX111217P00050000 -3807.39631068 VXX111217P00046000 at price 2.575; VXX: 46.29\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-01 00:00:00 strategy [INFO] Exit 3807 VXX111217P00050000 -3807 VXX111217P00046000  at price 3.5; PnL: 4568.4; VXX: 40.82\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-01 00:00:00 strategy [INFO] Portfolio Amount:102704.03 Allotted Portfolio Amount: 10270.403\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-01 00:00:00 strategy [INFO] Enter Position: +8930.78521739 VXX111217P00042000 -8930.78521739 VXX111217P00040000 at price 1.15; VXX: 40.82\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-08 00:00:00 strategy [INFO] Exit 8930 VXX111217P00042000 -8930 VXX111217P00040000  at price 0.755; PnL: -3705.95; VXX: 43.71\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-08 00:00:00 strategy [INFO] Portfolio Amount:103195.18 Allotted Portfolio Amount: 10319.518\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-08 00:00:00 strategy [INFO] Enter Position: +1750.55436811 VXX120121P00048000 -1750.55436811 VXX111217P00043000 at price 5.895; VXX: 43.71\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-14 00:00:00 strategy [INFO] Exit 1750 VXX120121P00048000 -1750 VXX111217P00043000  at price 6.62; PnL: 341.25; VXX: 40.77\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-14 00:00:00 strategy [INFO] Portfolio Amount:103151.43 Allotted Portfolio Amount: 10315.143\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-14 00:00:00 strategy [INFO] Enter Position: +3967.36269231 VXX120121P00044000 -3967.36269231 VXX120121P00040000 at price 2.6; VXX: 40.77\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-21 00:00:00 strategy [INFO] Exit 3967 VXX120121P00044000 -3967 VXX120121P00040000  at price 3.65; PnL: 3371.95; VXX: 33.76\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-21 00:00:00 strategy [INFO] Portfolio Amount:106225.855 Allotted Portfolio Amount: 10622.5855\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2011-12-21 00:00:00 strategy [INFO] Enter Position: +5245.72123457 VXX120121P00036000 -5245.72123457 VXX120121P00033000 at price 2.025; VXX: 33.76\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-10 00:00:00 strategy [INFO] Exit 5245 VXX120121P00036000 -5245 VXX120121P00033000  at price 2.64; PnL: 3750.175; VXX: 30.64\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-10 00:00:00 strategy [INFO] Portfolio Amount:109582.655 Allotted Portfolio Amount: 10958.2655\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-10 00:00:00 strategy [INFO] Enter Position: +3135.41216023 VXX120218P00033000 -3135.41216023 VXX120121P00030000 at price 3.495; VXX: 30.64\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-18 00:00:00 strategy [INFO] Exit 3135 VXX120218P00033000 -3135 VXX120121P00030000  at price 4.075; PnL: 2147.475; VXX: 30.15\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-18 00:00:00 strategy [INFO] Portfolio Amount:112074.98 Allotted Portfolio Amount: 11207.498\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-18 00:00:00 strategy [INFO] Enter Position: +8363.80447761 VXX120218P00032000 -8363.80447761 VXX120218P00030000 at price 1.34; VXX: 30.15\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-25 00:00:00 strategy [INFO] Exit 8363 VXX120218P00032000 -8363 VXX120218P00030000  at price 1.75; PnL: 2759.79; VXX: 26.65\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-25 00:00:00 strategy [INFO] Portfolio Amount:114625.695 Allotted Portfolio Amount: 11462.5695\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-01-25 00:00:00 strategy [INFO] Enter Position: +8716.78288973 VXX120218P00028000 -8716.78288973 VXX120218P00026000 at price 1.315; VXX: 26.65\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-03 00:00:00 strategy [INFO] Exit 8716 VXX120218P00028000 -8716 VXX120218P00026000  at price 1.745; PnL: 3529.98; VXX: 23.9869\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-03 00:00:00 strategy [INFO] Portfolio Amount:118635.055 Allotted Portfolio Amount: 11863.5055\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-03 00:00:00 strategy [INFO] Enter Position: +4995.16021053 VXX120317P00026000 -4995.16021053 VXX120218P00024000 at price 2.375; VXX: 23.9869\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-10 00:00:00 strategy [INFO] Exit 4995 VXX120317P00026000 -4995 VXX120218P00024000  at price 1.67; PnL: -3971.025; VXX: 27.872\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-10 00:00:00 strategy [INFO] Portfolio Amount:118235.455 Allotted Portfolio Amount: 11823.5455\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-10 00:00:00 strategy [INFO] Enter Position: +6158.09661458 VXX120317P00030000 -6158.09661458 VXX120317P00027000 at price 1.92; VXX: 27.872\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-23 00:00:00 strategy [INFO] Exit 6158 VXX120317P00030000 -6158 VXX120317P00027000  at price 2.6; PnL: 2155.3; VXX: 24.13\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-23 00:00:00 strategy [INFO] Portfolio Amount:119467.055 Allotted Portfolio Amount: 11946.7055\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-02-23 00:00:00 strategy [INFO] Enter Position: +17698.822963 VXX120317P00025000 -17698.822963 VXX120317P00024000 at price 0.675; VXX: 24.13\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-06 00:00:00 strategy [INFO] Exit 17698 VXX120317P00025000 -17698 VXX120317P00024000  at price 0.37; PnL: -3539.6; VXX: 26.03\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-06 00:00:00 strategy [INFO] Portfolio Amount:119644.035 Allotted Portfolio Amount: 11964.4035\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-06 00:00:00 strategy [INFO] Enter Position: +4147.10693241 VXX120421P00028000 -4147.10693241 VXX120317P00026000 at price 2.885; VXX: 26.03\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-14 00:00:00 strategy [INFO] Exit 4147 VXX120421P00028000 -4147 VXX120317P00026000  at price 2.85; PnL: -808.665; VXX: 21.9395\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-14 00:00:00 strategy [INFO] Portfolio Amount:118420.67 Allotted Portfolio Amount: 11842.067\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-14 00:00:00 strategy [INFO] Enter Position: +8643.84452555 VXX120421P00024000 -8643.84452555 VXX120421P00022000 at price 1.37; VXX: 21.9395\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-21 00:00:00 strategy [INFO] Exit 8643 VXX120421P00024000 -8643 VXX120421P00022000  at price 1.8; PnL: 3327.555; VXX: 18.36\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-21 00:00:00 strategy [INFO] Portfolio Amount:121748.225 Allotted Portfolio Amount: 12174.8225\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-21 00:00:00 strategy [INFO] Enter Position: +18446.7007576 VXX120421P00019000 -18446.7007576 VXX120421P00018000 at price 0.66; VXX: 18.36\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-26 00:00:00 strategy [INFO] Exit 18446 VXX120421P00019000 -18446 VXX120421P00018000  at price 0.98; PnL: 6548.33; VXX: 15.6685\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-26 00:00:00 strategy [INFO] Portfolio Amount:124146.205 Allotted Portfolio Amount: 12414.6205\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-26 00:00:00 strategy [INFO] Enter Position: +9196.01518519 VXX120421P00017000 -9196.01518519 VXX120421P00015000 at price 1.35; VXX: 15.6685\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-27 00:00:00 strategy [INFO] Exit 9196 VXX120421P00017000 -9196 VXX120421P00015000  at price 0.885; PnL: 0.0; VXX: 17.2\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-27 00:00:00 strategy [INFO] Portfolio Amount:123686.405 Allotted Portfolio Amount: 12368.6405\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-03-27 00:00:00 strategy [INFO] Enter Position: +18323.9118519 VXX120421P00018000 -18323.9118519 VXX120421P00017000 at price 0.675; VXX: 17.2\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-04-09 00:00:00 strategy [INFO] Exit 18323 VXX120421P00018000 -18323 VXX120421P00017000  at price 0.36; PnL: -4763.98; VXX: 18.982\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-04-09 00:00:00 strategy [INFO] Portfolio Amount:115441.055 Allotted Portfolio Amount: 11544.1055\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-04-09 00:00:00 strategy [INFO] Enter Position: +4943.94239829 VXX120519P00021000 -4943.94239829 VXX120421P00019000 at price 2.335; VXX: 18.982\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-04-18 00:00:00 strategy [INFO] Exit 4943 VXX120519P00021000 -4943 VXX120421P00019000  at price 2.785; PnL: 2520.93; VXX: 18.25\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-04-18 00:00:00 strategy [INFO] Portfolio Amount:118233.85 Allotted Portfolio Amount: 11823.385\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-04-18 00:00:00 strategy [INFO] Enter Position: +8725.74538745 VXX120519P00020000 -8725.74538745 VXX120519P00018000 at price 1.355; VXX: 18.25\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-01 00:00:00 strategy [INFO] Exit 8725 VXX120519P00020000 -8725 VXX120519P00018000  at price 1.79; PnL: 3708.125; VXX: 16.01\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-01 00:00:00 strategy [INFO] Portfolio Amount:121767.475 Allotted Portfolio Amount: 12176.7475\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-01 00:00:00 strategy [INFO] Enter Position: +18174.25 VXX120519P00017000 -18174.25 VXX120519P00016000 at price 0.67; VXX: 16.01\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-04 00:00:00 strategy [INFO] Exit 18174 VXX120519P00017000 -18174 VXX120519P00016000  at price 0.465; PnL: -3816.54; VXX: 17.23\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-04 00:00:00 strategy [INFO] Portfolio Amount:118768.765 Allotted Portfolio Amount: 11876.8765\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-04 00:00:00 strategy [INFO] Enter Position: +5602.30023585 VXX120616P00019000 -5602.30023585 VXX120519P00017000 at price 2.12; VXX: 17.23\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-16 00:00:00 strategy [INFO] Exit 5602 VXX120616P00019000 -5602 VXX120519P00017000  at price 1.375; PnL: -4733.69; VXX: 20.07\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-16 00:00:00 strategy [INFO] Portfolio Amount:112130.395 Allotted Portfolio Amount: 11213.0395\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-16 00:00:00 strategy [INFO] Enter Position: +8430.85676692 VXX120616P00022000 -8430.85676692 VXX120616P00020000 at price 1.33; VXX: 20.07\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-18 00:00:00 strategy [INFO] Exit 8430 VXX120616P00022000 -8430 VXX120616P00020000  at price 0.965; PnL: -1854.6; VXX: 22.36\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-18 00:00:00 strategy [INFO] Portfolio Amount:113732.095 Allotted Portfolio Amount: 11373.2095\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-18 00:00:00 strategy [INFO] Enter Position: +8816.44147287 VXX120616P00024000 -8816.44147287 VXX120616P00022000 at price 1.29; VXX: 22.36\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-29 00:00:00 strategy [INFO] Exit 8816 VXX120616P00024000 -8816 VXX120616P00022000  at price 1.75; PnL: 1322.4; VXX: 19.22\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-29 00:00:00 strategy [INFO] Portfolio Amount:113379.455 Allotted Portfolio Amount: 11337.9455\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-29 00:00:00 strategy [INFO] Enter Position: +17578.2100775 VXX120616P00020000 -17578.2100775 VXX120616P00019000 at price 0.645; VXX: 19.22\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-30 00:00:00 strategy [INFO] Exit 17578 VXX120616P00020000 -17578 VXX120616P00019000  at price 0.46; PnL: 0.0; VXX: 20.55\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-30 00:00:00 strategy [INFO] Portfolio Amount:112588.445 Allotted Portfolio Amount: 11258.8445\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-05-30 00:00:00 strategy [INFO] Enter Position: +19752.3587719 VXX120616P00021000 -19752.3587719 VXX120616P00020000 at price 0.57; VXX: 20.55\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-06-01 00:00:00 strategy [INFO] Exit 19752 VXX120616P00021000 -19752 VXX120616P00020000  at price 0.34; PnL: -4147.92; VXX: 22.58\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2012-06-01 00:00:00 strategy [INFO] Portfolio Amount:109329.365 Allotted Portfolio Amount: 10932.9365\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "WARNING: Some output was deleted.\n"
     ]
    }
   ],
   "source": [
    "from pyalgotrade.stratanalyzer import returns\n",
    "from pyalgotrade import plotter\n",
    "from pyalgotrade.utils import stats\n",
    "from pyalgotrade.stratanalyzer import drawdown\n",
    "from pyalgotrade.stratanalyzer import trades\n",
    "\n",
    "#feed.reset()\n",
    "myStrategy = MyStrategy(feed, \"VXX\", useAdjustedClose=True)\n",
    "\n",
    "returnsAnalyzer = returns.Returns()\n",
    "myStrategy.attachAnalyzer(returnsAnalyzer)\n",
    "drawDownAnalyzer = drawdown.DrawDown()\n",
    "myStrategy.attachAnalyzer(drawDownAnalyzer)\n",
    "tradesAnalyzer = trades.Trades()\n",
    "myStrategy.attachAnalyzer(tradesAnalyzer)\n",
    "\n",
    "# Attach the plotter to the strategy.\n",
    "plt = plotter.StrategyPlotter(myStrategy, plotAllInstruments=False, plotBuySell=False)\n",
    "myStrategy.run()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "2747b1480cb211c1e53d6141f18f3eba7fbeb91f"
     },
     "execution_count": 11,
     "metadata": {
     },
     "output_type": "execute_result"
    }
   ],
   "source": [
    "plt.plot()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": false
   },
   "source": [
    "## TO-DO: Get PyAlgoTrade to fill on the same bar\n",
    "## See also https://groups.google.com/forum/#!searchin/pyalgotrade/next$20bar%7Csort:relevance/pyalgotrade/beybdpkfWNc/CBiVIUbNBgAJ"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": false
   },
   "source": [
    "## TO-DO: Verify the spread; add a hedge order"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 0,
   "metadata": {
    "collapsed": true
   },
   "outputs": [
   ],
   "source": [
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.15rc1"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}